package com.nisum.omd.listener;

import com.nisum.omd.domain.Order;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.kafka.annotation.KafkaListener;
import org.springframework.mail.javamail.JavaMailSender;
import org.springframework.mail.javamail.MimeMessageHelper;
import org.springframework.stereotype.Service;

import javax.mail.internet.MimeMessage;

@Service
public class OmdConsumerListener {

    @Autowired
    private JavaMailSender sender;
    Logger logger = LoggerFactory.getLogger(OmdConsumerListener.class);

    public static final String TOPIC = "TOPIC_OMD_ORDER_DATA";
    public static final String GROUP_ID = "OMD_ORDER_DATA_GROUP";


    @KafkaListener(topics = TOPIC, groupId = GROUP_ID, containerFactory = "orderKafkaListenerContainerFactory")
    public void consumeMessage(Order order) {
        validateOrder(order);
        logger.info("Consumed Order Data with Order Number: " + order.getOrderNum());
        /*try {
            sendEmail();
            logger.info("Email Sent Successfully!");
        } catch (Exception ex) {
            logger.error("Exception while sending the mail!" + ex.getMessage());
        }*/
    }
    private void sendEmail() throws Exception{
        MimeMessage message = sender.createMimeMessage();
        MimeMessageHelper helper = new MimeMessageHelper(message);
        helper.setTo("reciever@gmail.com");
        helper.setText("Your Order Placed Successfully !!");
        helper.setSubject("Order Confirmation");

        sender.send(message);
    }

    private void validateOrder(Order order){
        if(order.getOrderNum() != null && order.getCustomerId() != null){
                logger.info("Your Order is Validated Successfully");

        }else{
            throw new RuntimeException("Your Order is Invalid: Please check again");
        }
    }

}
